# `#!python class QONetwork(keras.Model)`

## Introduction

This class contains actual implementation of neural network for solving quantum
oscillator problem.

::: nneve.quantum_oscillator.QONetwork
